// Copyright 2007, Massachusetts Institute of Technology.
// The use of this code is permitted for research only. There is
// absolutely no warranty for this software.
//
// Author: John Lee (jjl@mit.edu)
//
// This returns 384-dimensional vectors, which is the concatenation of
// three 128-dimensional SIFT descriptors. Each SIFT descriptor is
// one HSV component.
//

#ifndef EXTRACTOR_HSV_SIFT_EXTRACTOR_H
#define EXTRACTOR_HSV_SIFT_EXTRACTOR_H

#include <stdio.h>
#include <vector>
#include <string>
#include "extractor.h"
#include "interest_point.h"
#include "point_set/point-set.h"
#include "point_set/point.h"

using namespace std;
using namespace libpmk;

namespace libpmk_features {

class HSVSIFTExtractor : public Extractor {
public:
  HSVSIFTExtractor() { }
  virtual ~HSVSIFTExtractor() { }
  virtual PointSet ExtractFeatures(const vector<InterestPoint>& points,
                                   const string& image) const;
  void SetBinaryPath(const string& path);
  static void ConvertRGBToHSV(int R, int G, int B,
                              int* H, int* S, int *v);

private:
  SIFTExtractor sift_extractor_;
};


}  // namespace libpmk_features

#endif  // EXTRACTOR_HSV_SIFT_EXTRACTOR_H
